diff options
Diffstat (limited to 'content/posts/nested-postgres-results/composite-array-agg.txt')
| -rw-r--r-- | content/posts/nested-postgres-results/composite-array-agg.txt | 33 |
1 files changed, 0 insertions, 33 deletions
diff --git a/content/posts/nested-postgres-results/composite-array-agg.txt b/content/posts/nested-postgres-results/composite-array-agg.txt deleted file mode 100644 index eb5c507..0000000 --- a/content/posts/nested-postgres-results/composite-array-agg.txt +++ /dev/null @@ -1,33 +0,0 @@ -GroupAggregate (cost=14206.02..16920.03 rows=8849 width=36) (actual time=17.442..24.779 rows=10000 loops=1) - Output: accommodation_id, array_agg(ROW(date, price)) - Group Key: overrides.accommodation_id - Buffers: shared hit=6442 - -> Gather Merge (cost=14206.02..16702.25 rows=21433 width=13) (actual time=17.433..20.521 rows=20000 loops=1) - Output: accommodation_id, date, price - Workers Planned: 2 - Workers Launched: 2 - Buffers: shared hit=6442 - -> Sort (cost=13206.00..13228.33 rows=8930 width=13) (actual time=14.503..14.704 rows=6667 loops=3) - Output: accommodation_id, date, price - Sort Key: overrides.accommodation_id - Sort Method: quicksort Memory: 424kB - Buffers: shared hit=6442 - Worker 0: actual time=13.119..13.313 rows=6171 loops=1 - Sort Method: quicksort Memory: 385kB - Buffers: shared hit=2007 - Worker 1: actual time=13.642..13.847 rows=6437 loops=1 - Sort Method: quicksort Memory: 394kB - Buffers: shared hit=2086 - -> Parallel Seq Scan on public.overrides (cost=0.00..12619.99 rows=8930 width=13) (actual time=0.011..13.689 rows=6667 loops=3) - Output: accommodation_id, date, price - Filter: ((overrides.date >= '2025-07-01'::date) AND (overrides.date < '2025-07-08'::date)) - Rows Removed by Filter: 326666 - Buffers: shared hit=6370 - Worker 0: actual time=0.009..12.361 rows=6171 loops=1 - Buffers: shared hit=1971 - Worker 1: actual time=0.010..12.859 rows=6437 loops=1 - Buffers: shared hit=2050 -Planning: - Buffers: shared hit=129 -Planning Time: 0.272 ms -Execution Time: 25.133 ms |
